![Guanin Logo](https://i.ibb.co/whKb1vY/logoguanin-156x156.png) <img src="https://i.imgur.com/aWneKnL.png" width="100" height="100">
<a href="https://genpob.eu"><img src="https://genpob.eu/static/image/GenPob_logo.png" height="100">
<a href="https://www.genvip.eu"><img src="https://i.imgur.com/4gpxYQV.png" height="100">



# GUANIN

| GUi-driven Analyser for Nanostring Interactive Normalization |

[Explore the docs](https://github.com/julimontoto/guanin)

[Report Bug](https://github.com/julimontoto/guanin/issues)

[Request Feature](https://github.com/github_username/repo_name/issues)

## Table of Contents

* [About Guanin](#about-guanin)
* [Getting Started](#getting-started)
  * [Prerequisites](#prerequisites)
  * [Installation](#installation)
* [Usage](#usage)
* [Roadmap](#roadmap)
* [Contributing](#contributing)
* [License](#license)
* [Contact](#contact)
* [Acknowledgments](#acknowledgements)


![Guanin Screen Shot](https://i.imgur.com/Bz6Yvpd.png)

## Getting started

### Prerequisites

GUANIN should run under Linux, MacOS and Windows. You'll need Python >= 3.9 installed.

## Installation

### Linux

#### Installing with pip

    $ pip install guanin

#### Installing from Repo

    $ git clone https://github.com/julimontoto/guanin.git
  
    $ pip install poetry
  
    $ poetry install

#### [OR] Installing from .whl file

    $ pip install python3-pip
  
    $ pip install --upgrade pip
  
    $ pip install guanin-0.x.x-py3-none-any.whl

### Run

    $ guanin

In case this is not working properly, you will need to find where Guanin has been installed and add it to Path environment variable. This is a common procedure usually fixed by:
```
$ export PATH=/path/where/guanin/is/installed:$PATH
```

This will add it to path for this session, but can be made permanent by adding the above command to the bottom of your `.bashrc` file (usually located in your home directory (`/home/yourusername/.bashrc`)).

### MAC

Assuming python ^3.9 is installed.

    % pip install python3-pip
  
    % pip install --upgrade pip
 
    % pip install guanin

### Run

    % guanin


### Windows

Install python3 and pip.
Visual Studio Build Tools 14+ might be required.

> pip install guanin

#### Run

> guanin

In case this is not working properly, you will need to find where Guanin has been installed and add it to Path environment variable. (Usually ~/Pythonxxx/scripts)

Check INSTALL.txt for further details.

## Usage

### The CLI

Open a console and from any path, run the following:

    $ guanin-cli

### The GUI

A simple GUI is included using [pyQT6](https://pypi.org/project/PyQt6/).

From a console, launch the GUI with:

   $ guanin

This *executable* is installed in your PATH. You can find it and launch it with a double-click. Although, running it through the console will provide further information about the execution of the program.

## Workflow

<img src="https://i.imgur.com/UZBcIN5.png" height="500">

## Contributing

Pull requests are only welcome if both the following are true:

1. They include at least some test.

2. They solve a bug.

We don't accept pull requests of enhancements, new requirements, "It would be
nice if...", and so on. If that is your case, fork and develop.

### For internal usage only

## License

GUANIN: GUi-driven Analyzer for Nanostring Interactive Normalization. 
Copyright (C) 2023, Montoto-Louzao et al.

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

Contact: juli.mlouzao@gmail.com | GENVIP - GENPOB
Instituto de Investigación Sanitaria de Santiago de Compostela.
Complejo Hospitalario Universitario de Santiago de Compostela.

Distributed under the GPLV3 License. See `LICENSE.txt` for more information.

## Contact

Julián Montoto-Louzao - [@julimontoto](https://twitter.com/julimontoto) -  juli.mlouzao@gmail.com

GUANIN: [https://github.com/julimontoto/guanin](https://github.com/julimontoto/guanin)

## Acknowledgements

GENVIP RESEARCH GROUP (www.genvip.eu).
GENPOB RESEARCH GROUP(www.genpob.eu).
María José Martín Santamaría (UDC).
Instituto Sanitario de Santiago de Compostela (IDIS).
Complejo Hospitalario de Santiago de Compostela (CHUS).
Obra Social Pediatría (OSP).
